@@ -9,7 +9,7 @@ from ..context import get_default_gateway
 from ..paramtypes import CanFrameType, CanFilterType, CanbusRange
 from ..status import run_job_output
 
-@click.group(name='canbus')
+@click.group(name='canbus', hidden=True)
 def canbus():
     """
         Lager CAN Bus commands
@@ -18,8 +18,10 @@ def canbus():
 
 @canbus.command('list')
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
-def list_(ctx, gateway):
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
+def list_(ctx, gateway, dut):
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -32,9 +34,10 @@ def list_(ctx, gateway):
 @canbus.command()
 @click.pass_context
 @click.argument('interfaces', type=CanbusRange())
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.option('--bitrate', required=True, type=click.INT, help='bus bitrate e.g. 500000, 250000, etc')
-def up(ctx, interfaces, gateway, bitrate):
+def up(ctx, interfaces, gateway, dut, bitrate):
     """
         Bring up the CAN Bus at the specified bitrate
 
@@ -51,6 +54,7 @@ def up(ctx, interfaces, gateway, bitrate):
 
         Use `lager canbus list` to view available INTERFACES.
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -61,8 +65,9 @@ def up(ctx, interfaces, gateway, bitrate):
 @canbus.command()
 @click.pass_context
 @click.argument('interfaces', type=CanbusRange())
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
-def down(ctx, interfaces, gateway):
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
+def down(ctx, interfaces, gateway, dut):
     """
         Bring down the CAN Bus at the specified bitrate
 
@@ -79,6 +84,7 @@ def down(ctx, interfaces, gateway):
 
         Use `lager canbus list` to view available INTERFACES.
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -89,10 +95,11 @@ def down(ctx, interfaces, gateway):
 
 @canbus.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.argument('interface', type=click.INT, required=True)
 @click.argument('can_frames', required=True, nargs=-1, type=CanFrameType())
-def send(ctx, gateway, interface, can_frames):
+def send(ctx, gateway, interface, can_frames, dut):
     """
         Send a frame on the specified CAN bus
 
@@ -123,7 +130,7 @@ def send(ctx, gateway, interface, can_frames):
             5A1#11.2233.44556677.88 / 123#DEADBEEF / 5AA# / 123##1 / 213##311
             1F334455#1122334455667788 / 123#R for remote transmission request.
     """
-
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -134,10 +141,11 @@ def send(ctx, gateway, interface, can_frames):
 
 @canbus.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.argument('interface', type=click.INT, required=True)
 @click.argument('filters', required=False, nargs=-1, type=CanFilterType())
-def dump(ctx, gateway, interface, filters):
+def dump(ctx, gateway, dut, interface, filters):
     """
         Dump CAN bus traffic (use Ctrl-C to terminate)
 
@@ -159,6 +167,7 @@ def dump(ctx, gateway, interface, filters):
         lager canbus dump 0 123:7FF
             (matches CAN ID 123 - including EFF and RTR frames on interface 0)
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
