@@ -7,14 +7,16 @@ import click
 from .. import SUPPORTED_DEVICES, SUPPORTED_INTERFACES
 from ..context import get_default_gateway
 
-@click.command(name='chip-erase')
+@click.command(name='chip-erase', hidden=True)
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.option('--device', help='Target device type', type=click.Choice(SUPPORTED_DEVICES), required=True)
 @click.option('--interface', help='Target interface', type=click.Choice(SUPPORTED_INTERFACES), default='ftdi', show_default=True)
 @click.option('--transport', help='Target transport', type=click.Choice(['swd', 'jtag', 'hla_swd', 'dapdirect_swd']), default='swd', show_default=True)
 @click.option('--speed', help='Target interface speed in kHz', required=False, default='adaptive', show_default=True)
-def chip_erase(ctx, gateway, device, interface, transport, speed):
+def chip_erase(ctx, gateway, dut, device, interface, transport, speed):
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
