@@ -54,10 +54,10 @@ from .pigpio.commands import pigpio
 from .spi.commands import spi
 from .i2c.commands import i2c
 from .pip.commands import pip
-from .util import check_version
 from .net.commands import net
 from .rtt.commands import rtt
 from .usb.commands import usb
+from .hello.commands import hello
 
 def _decode_environment():
     for key in os.environ:
@@ -87,8 +87,6 @@ def cli(ctx=None, see_version=None, debug=False, colorize=False, version_check=T
         os_args = sys.argv[1:]
         help_invoked = '--help' in os_args
         skip_auth = ctx.invoked_subcommand in ('login', 'logout', 'set', 'get', 'devenv', 'exec') or help_invoked
-        if version_check and not skip_auth:
-            check_version('lager-cli', __version__)
         setup_context(ctx, debug, colorize, skip_auth, interpreter)
 
 cli.add_command(_gateway)
@@ -129,6 +127,7 @@ cli.add_command(pip)
 cli.add_command(net)
 cli.add_command(rtt)
 cli.add_command(usb)
+cli.add_command(hello)
 
 def setup_context(ctx, debug, colorize, skip_auth, interpreter):
     """
