@@ -11,7 +11,7 @@ from ..context import get_default_gateway
 from ..exceptions import GatewayTimeoutError
 from ..paramtypes import HexParamType, VarAssignmentType
 
-@click.command()
+@click.command(hidden=True)
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
 @click.option(
@@ -85,7 +85,7 @@ def connect(ctx, gateway, snr, device, interface, transport, speed, workareasize
     elif resp.get('already_running') == 'ok':
         click.secho('Debugger already connected, ignoring', fg='green')
 
-@click.command()
+@click.command(hidden=True)
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
 def disconnect(ctx, gateway):
