@@ -762,3 +762,7 @@ def get_ci_environment():
         return CIEnvironment.GENERIC_CI
 
     return CIEnvironment.HOST
+
+def get_impl_path(filename):
+    base = os.path.dirname(__file__)
+    return os.path.join(base, 'impl', filename)
