@@ -26,7 +26,7 @@ def run_grafana_tunnel(ctx, host, port, gateway):
         if ctx.obj.debug:
             raise
 
-@click.command()
+@click.command(hidden=True)
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway')
 @click.option('--host', default='localhost', help='interface for grafana to bind. '
