@@ -7,7 +7,7 @@ import math
 import click
 from ..status import run_job_output
 
-@click.group(name='job')
+@click.group(name='job', hidden=True)
 def job():
     """
         Lager job commands
