@@ -15,9 +15,6 @@ def lister():
     """
     pass
 
-
-@lister.command()
-@click.pass_context
 def gateways(ctx):
     """
         List a user's gateways
@@ -37,6 +34,23 @@ def gateways(ctx):
         table.add_row([gateway['name'], gateway['id']])
     click.echo(table.draw())
 
+
+@lister.command('gateways', hidden=True)
+@click.pass_context
+def gateways_handler(ctx):
+    """
+        List a user's gateways
+    """
+    gateways(ctx)
+
+@lister.command('duts')
+@click.pass_context
+def duts_handler(ctx):
+    """
+        List a user's DUTs
+    """
+    gateways(ctx)
+
 @lister.command()
 def supported_devices():
     """
