@@ -29,7 +29,7 @@ def run_openocd_tunnel(ctx, host, port, gateway, rtt, rtt_port):
         if ctx.obj.debug:
             raise
 
-@click.command()
+@click.command(hidden=True)
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
 @click.option('--host', default='localhost', help='interface for telnet to bind. '
