@@ -13,7 +13,7 @@ def do_reset(session, gateway, halt, mcu=None):
     """
     return session.reset_dut(gateway, halt, mcu)
 
-@click.command()
+@click.command(hidden=True)
 @click.pass_context
 @click.option('--gateway', '--dut', required=False, help='ID of gateway to which DUT is connected')
 @click.option('--halt', is_flag=True, help='Halt the DUT after reset. Default: do not halt', default=False, show_default=True)
