@@ -6,7 +6,7 @@
 import click
 from ..context import get_default_gateway
 
-@click.command()
+@click.command(hidden=True)
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
 def run(ctx, gateway):
