@@ -339,7 +339,7 @@ async def display_job_output(connection_params, test_runner, interactive, line_e
 
 def run_job_output(connection_params, test_runner, interactive, line_ending, message_timeout,
         overall_timeout, eof_timeout, debug=False, success_regex=None, failure_regex=None,
-        opost=False, serial_channel=0, ptty=False, catch_sigint=False):
+        opost=False, serial_channel=0, ptty=False, catch_sigint=False, disconnect=None):
     """
         Run async task to get job output from websocket
     """
@@ -411,3 +411,7 @@ def run_job_output(connection_params, test_runner, interactive, line_ending, mes
         if debug:
             raise
         click.get_current_context().exit(1)
+    finally:
+        if disconnect:
+            session = click.get_current_context().obj.session
+            session.stop_debugger(disconnect)
