@@ -46,7 +46,8 @@ def do_uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, x
 
 @click.command()
 @click.pass_context
-@click.option('--gateway', '--dut', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.option('--serial-device', '--serial-port', help='Gateway serial port device path', metavar='path')
 @click.option('--baudrate', help='Serial baud rate', type=int, default=None)
 @click.option('--bytesize', help='Number of data bits', type=click.Choice(['5', '6', '7', '8']), default=None)
@@ -68,11 +69,12 @@ def do_uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, x
 @click.option('--opost/--no-opost', help=r'Enable implementation-defined output processing for your local output terminal. Typically this will convert \n to \r\n on output', is_flag=True, default=False, show_default=True)
 @click.option('--serial-channel', help=r'Select a specific UART channel (for use with Test Fixture)', type=int, default=0)
 @click.option('--fake-tty', help=r'Create a fake serial port (linux ptty)', is_flag=True, default=False, show_default=True)
-def uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, xonxoff, rtscts, dsrdtr,
+def uart(ctx, gateway, dut, serial_device, baudrate, bytesize, parity, stopbits, xonxoff, rtscts, dsrdtr,
          test_runner, interactive, message_timeout, overall_timeout, eof_timeout, display_job_id, line_ending, opost, serial_channel, fake_tty):
     """
         Connect to UART on a DUT.
     """
+    gateway = gateway or dut
     if interactive:
         if not sys.stdin.isatty():
             click.echo('stdin is not a tty!', err=True)
