@@ -28,14 +28,16 @@ def run_webcam_tunnel(ctx, host, port, gateway):
 
 @click.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.option('--host', default='localhost', help='interface for webcam to bind. '
               'Use --host \'*\' to bind to all interfaces.', show_default=True)
 @click.option('--port', default=8081, help='Port for webcam', show_default=True)
-def webcam(ctx, gateway, host, port):
+def webcam(ctx, gateway, dut, host, port):
     """
 
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
