@@ -9,7 +9,7 @@ from texttable import Texttable
 
 from ..context import get_default_gateway
 
-@click.group(name='wifi')
+@click.group(name='wifi', hidden=True)
 def _wifi():
     """
         Lager wifi commands
@@ -19,11 +19,13 @@ def _wifi():
 
 @_wifi.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway')
-def status(ctx, gateway):
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
+def status(ctx, gateway, dut):
     """
         Get the current WiFi Status of the gateway
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -38,14 +40,16 @@ def status(ctx, gateway):
 
 @_wifi.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.option('--interface', required=False, help='Wireless interface to use')
-def access_points(ctx, gateway, interface=None):
+def access_points(ctx, gateway, dut, interface=None):
     """
         Get WiFi access points visible to the gateway
     """
     # TODO implement table for ext wifi
 
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -69,14 +73,16 @@ def access_points(ctx, gateway, interface=None):
 
 @_wifi.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.option('--ssid', required=True, help='SSID of the network to connect to')
 @click.option('--interface', help='Wireless interface to use', default='wlan0', show_default=True)
 @click.option('--password', required=False, help='Password of the network to connect to', default='')
-def connect(ctx, gateway, ssid, interface, password=''):
+def connect(ctx, gateway, dut, ssid, interface, password=''):
     """
         Connect the gateway to a new network
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
@@ -89,13 +95,15 @@ def connect(ctx, gateway, ssid, interface, password=''):
 
 @_wifi.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway')
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected', hidden=True)
+@click.option('--dut', required=False, help='ID of DUT')
 @click.confirmation_option(prompt='An ethernet connection will be required to bring the gateway back online. Proceed?')
 @click.argument('SSID', required=True)
-def delete_connection(ctx, gateway, ssid):
+def delete_connection(ctx, gateway, dut, ssid):
     """
         Delete the specified network from the gateway
     """
+    gateway = gateway or dut
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
